program test_get_1_outerm

  use, intrinsic:: ISO_FORTRAN_ENV

  ! Libraries:
  use jumble, only: new_unit, count_lines, deg_to_rad

  use config_m, only: config
  use derived_types, only: eddy, shpc_slice_handler, null_ssh_contour, &
       missing_speed
  use get_1_outerm_m, only: get_1_outerm
  use input_ssh_m, only: input_ssh
  use shpc_close_m, only: shpc_close
  use shpc_create_m, only: shpc_create
  use write_eddy_m, only: write_eddy

  implicit none

  integer unit, n, l, date

  real, allocatable:: ssh(:, :)
  ! (1 - max_radius(1):nlon + max_radius(1), nlat) if the grid is periodic
  ! in longitude, else (nlon, nlat). Sea-surface height, in m.

  real, allocatable:: u(:, :), v(:, :)
  ! (1 - max_radius(1):nlon + max_radius(1), nlat) if periodic, else
  ! (nlon, nlat) wind, in m s-1

  integer:: ind_targ_extr(2) = [19, 11]
  ! indices in the two dimensions of target extremum

  real:: innermost_level = 0.2933
  ! level of innermost contour, for each extremum
  
  logical:: cyclone = .true.

  real corner_deg(2), corner(2)
  ! longitude and latitude of the corner of the whole grid, in degrees
  ! and in rad

  real step_deg(2), step(2) ! longitude and latitude steps, in degrees and rad

  integer nlon, nlat
  ! size of ssh array in input NetCDF, assuming no repeated point if
  ! the grid is global

  logical periodic ! grid is periodic in longitude
  TYPE(shpc_slice_handler) hshp
  type(eddy) e

  real, allocatable:: outside_points(:, :) ! (2, :) longitude and
  ! latitude, in rad, of all the significant extrema, except the
  ! target extremum

  namelist /main_nml/ ind_targ_extr, innermost_level, cyclone

  !----------------------------------------------------------------

  write(unit = error_unit, nml = main_nml)
  write(unit = error_unit, fmt = *) &
       "test_get_1_outerm: Enter namelist main_nml."
  read(unit = *, nml = main_nml)
  write(unit = *, nml = main_nml)
  print *, "test_get_1_outerm: date = ?"
  read *, date
  call config(exist = .false.)
  call input_ssh(corner, step, nlon, nlat, periodic, ssh, u, v, corner_deg, &
       step_deg)
  print *, "test_get_1_outerm: Reading from outside_points.csv..."
  call new_unit(unit)
  open(unit, file = "outside_points.csv", status = "old", action = "read", &
       position = "rewind")
  call count_lines(unit, n)
  n = n - 2 ! 2 title lines
  allocate(outside_points(2, n))
  rewind(unit)
  read(unit, fmt = *)
  read(unit, fmt = *)

  do l = 1, n
     read(unit, fmt = *) outside_points(:, l)
  end do

  outside_points = outside_points * deg_to_rad
  close(unit)
  e%coord_extr = corner + (ind_targ_extr - 1) * step

  e%out_cont = get_1_outerm(cyclone, e%coord_extr, innermost_level, &
       outside_points, ssh, corner, step)

  if (e%out_cont%closed) then
     e%ssh_extr = ssh(ind_targ_extr(1), ind_targ_extr(2))
     e%cyclone = cyclone
     e%speed_cont = null_ssh_contour()
     e%max_speed = missing_speed
     e%radius4 = - 1
     e%valid = .true.
     call shpc_create(hshp, shpc_dir = "SHPC", cyclone = cyclone, slice = 0)
     call write_eddy(e, hshp, date, i = 1)
     write(hshp%unit, fmt = *) 0
     CALL shpc_close(hshp)
     print *, 'test_get_1_outerm: Created "SHPC".'
  else
     print *, "test_get_1_outerm: Could not find an outermost contour."
  end if

end program test_get_1_outerm
